@@ -1,6 +1,6 @@
-#' @title Repeated Spatiotemporal Cluster Resampling
+#' @title Repeated "Leave-location-and-time-out" resampling.
 #'
-#' @template rox_sptcv_cluto
+#' @template rox_sptcv_cstf
 #'
 #' @references
 #' `r format_bib("zhao2002")`
@@ -97,7 +97,7 @@ ResamplingRepeatedSptCVCstf = R6Class("ResamplingRepeatedSptCVCstf",
     #'   A task to instantiate.
     instantiate = function(task) {
 
-      assert_task(task)
+      mlr3::assert_task(task)
       checkmate::assert_multi_class(task, c("TaskClassifST", "TaskRegrST"))
       checkmate::assert_subset(self$time_var,
         choices = task$feature_names,
