@@ -1,6 +1,5 @@
 #' @title Spatioemporal Cluster Resampling
 #'
-#' @import mlr3
 #' @template rox_sptcv_cluto
 #'
 #' @references
@@ -101,7 +100,7 @@ ResamplingSptCVCluto = R6Class("ResamplingSptCVCluto",
 
       mlr3misc::require_namespaces("skmeans", quietly = TRUE)
 
-      assert_task(task)
+      mlr3::assert_task(task)
       checkmate::assert_multi_class(task, c("TaskClassifST", "TaskRegrST"))
       checkmate::assert_subset(self$time_var, choices = task$feature_names)
       groups = task$groups
